pept.scanners API documentation

# Module `pept.scanners`

Source code

    #!/usr/bin/env python3
    # -*- coding: utf-8 -*-

    # File   : __init__.py
    # License: License: GNU v3.0
    # Author : Andrei Leonard Nicusan <a.l.nicusan@bham.ac.uk>
    # Date   : 20.08.2019

    from    .parallel_screens    import  *
    from    .modular_camera      import  *

    __author__ =        "Andrei Leonard Nicusan, Sam Manger"
    __credits__ =       ["Andrei Leonard Nicusan", "Kit Windows-Yule", "Sam Manger"]
    __license__ =       "GNU v3.0"
    __version__ =       "0.1.0"
    __maintainer__ =    "Andrei Leonard Nicusan"
    __email__ =         "a.l.nicusan@bham.ac.uk"
    __status__ =        "Development"

## Sub-modules

`pept.scanners.modular_camera`
`pept.scanners.parallel_screens`